Source filenames of a ModelArray object
sources.RdRetrieve the named list of source filename vectors from a ModelArray. Each element of the list corresponds to one scalar and contains a character vector of filenames, one per input file/subject.
Arguments
- x
A ModelArray object.
Examples
if (FALSE) { # \dontrun{
ma <- ModelArray("data.h5", scalar_types = c("FD"))
sources(ma) # named list
sources(ma)[["FD"]] # character vector of filenames
} # }